mod random_number;
pub use random_number::random_number;

mod random_bool;
pub use random_bool::random_bool;

mod random_str;
pub use random_str::{random_str, random_str_rg};

mod swap;
pub use swap::swap;

mod drain_filter;
pub use drain_filter::drain_filter;

#[cfg(feature = "async")]
pub mod futures;
